CLI documentation
=================

The **stac-asset** Command-Line Interface (CLI) provides a text-based way of using the library.

.. click:: stac_asset._cli:cli
    :prog: stac-asset
    :nested: full
